@@ -164,9 +164,9 @@ DEFUN_NEW("ROW-MAJOR-AREF", object, fLrow_major_aref, LISP, 2, 2,
     case aet_uchar:
       return small_fixnum(x->ust.ust_self[i]);
     case aet_short:
-      return make_fixnum(SHORT(x, i));
+      return make_fixnum(SHORT_GCL(x, i));
     case aet_ushort:
-      return small_fixnum(USHORT(x, i));
+      return make_fixnum(USHORT_GCL(x, i));
 
     default:
       FEerror("unknown array type",0);
@@ -180,6 +180,12 @@ DEFUN_NEW("ROW-MAJOR-AREF", object, fLrow_major_aref, LISP, 2, 2,
     return(Cnil);
   }
 }
+#ifdef STATIC_FUNCTION_POINTERS
+object
+fLrow_major_aref(object x,fixnum i) {
+  return FFN(fLrow_major_aref)(x,i);
+}
+#endif
 
 object
 aset1(object x,fixnum i,object val) {
@@ -234,11 +240,11 @@ DEFUN_NEW("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,(object x, fix
       break;
     case aet_short:
       ASSURE_TYPE(val,t_fixnum);
-      SHORT(x, i) = Mfix(val);
+      SHORT_GCL(x, i) = Mfix(val);
       break;
     case aet_ushort:
       ASSURE_TYPE(val,t_fixnum);
-      USHORT(x, i) = Mfix(val);
+      USHORT_GCL(x, i) = Mfix(val);
       break;
     default:
       FEerror("unknown array type",0);
@@ -255,10 +261,16 @@ DEFUN_NEW("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,(object x, fix
   }
   return val;
 }
+#ifdef STATIC_FUNCTION_POINTERS
+object
+fSaset1(object x, fixnum i,object val) {
+  return FFN(fSaset1)(x,i,val);
+}
+#endif
 
 DEFUNO_NEW("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
-       IO, OO, OO,void,siLaset,(object x,fixnum i,object y, ...),"")
-{ int i1;
+       OO, OO, OO,void,siLaset,(object x,object ii,object y, ...),"")
+{ int i,i1;
   int n = VFUN_NARGS;
   va_list ap;
   if (type_of(x) == t_array)
@@ -267,9 +279,9 @@ DEFUNO_NEW("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
      int rank = n - 2; 
      if (x->a.a_rank != rank)
        FEerror(" ~a has wrong rank",1,x);
-     if (rank == 0) return fSaset1(x,0,make_fixnum(i));
-/*      ASSURE_TYPE(ii,t_fixnum); */
-/*      i = fix(ii); */
+     if (rank == 0) return fSaset1(x,0,ii);
+     ASSURE_TYPE(ii,t_fixnum);
+     i = fix(ii);
      if (rank == 1)
        return fSaset1(x,i,y);
      va_start(ap,y);
@@ -309,12 +321,14 @@ DEFUNO_NEW("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
    }
   else 
     { 
-/*       ASSURE_TYPE(ii,t_fixnum); */
+     ASSURE_TYPE(ii,t_fixnum);
+     i = fix(ii);
       return fSaset1(x,i,y);
     }
    
 }
 
+
 DEFUNO_NEW("SVSET", object, fSsvset, SI, 3, 3, NONE, OO, IO, OO,
        OO,void,siLsvset,(object x,fixnum i,object val),"")
 { if (TYPE_OF(x) != t_vector
@@ -424,7 +438,11 @@ DEFUN_NEW("MAKE-VECTOR1",object,fSmake_vector1,SI,3,8,NONE,OI,
       }
     }
   }
-
+object 
+fSmake_vector1_1(fixnum n,fixnum elt_type,object staticp) {
+  VFUN_NARGS=3;
+  return FFN(fSmake_vector1)(n,elt_type,staticp);
+}
 
 
 static object DFLT_aet_object = Cnil;	
@@ -457,6 +475,12 @@ DEFUN_NEW("GET-AELTTYPE",object,fSget_aelttype,SI,1,1,NONE,OO,OO,OO,OO,(object x
     return make_fixnum(aet_lf);
   return make_fixnum(aet_object);
 }
+#ifdef STATIC_FUNCTION_POINTERS
+object
+fSget_aelttype(object x) {
+  return FFN(fSget_aelttype)(x);
+}
+#endif
 
 /* backward compatibility only:
    	(si:make-vector element-type 0
@@ -482,7 +506,7 @@ DEFUNO_NEW("MAKE-VECTOR",object,fSmake_vector,SI,7,8,NONE,
   /* 8 args */
 
   VFUN_NARGS = 8;
-  x = fSmake_vector1(Mfix(x1),  /* n */
+  x = FFN(fSmake_vector1)(Mfix(x1),  /* n */
 		     fix(fSget_aelttype(x0)), /*aelt type */
 		     x6, /* staticp */
 		     x3, /* fillp */ 
@@ -506,6 +530,8 @@ DEFUN_NEW("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
        object dimensions),"")
 {   
   int rank = length(dimensions);
+  if (rank > ARRAY_RANK_LIMIT)
+    FEerror("Array rank limit exceeded.",0);
   { object x,v;
     char *tmp_alloc;
     int dim =1,i; 
@@ -533,6 +559,15 @@ DEFUN_NEW("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
 	return x;
       }
  }}
+#ifdef STATIC_FUNCTION_POINTERS
+object
+fSmake_array1(fixnum elt_type,object staticp,object initial_element,object displaced_to,
+	      fixnum displaced_index_offset,object dimensions) {
+  return FFN(fSmake_array1)(elt_type,staticp,initial_element,
+			    displaced_to,displaced_index_offset,dimensions);
+}
+#endif
+
 
 /*
 (proclaim '(ftype (function (object t  *)) array-displacement1))
@@ -564,7 +599,7 @@ DEFUN_NEW("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
 /*  } */
 
 static void
-Larray_displacement(void) {
+FFN(Larray_displacement)(void) {
 
   object array,a;
   int s,n;
@@ -719,7 +754,7 @@ Iarray_element_type(object x)
 /* add diff to body of x and arrays diisplaced to it */
 
 void
-adjust_displaced(object x, int diff)
+adjust_displaced(object x, long diff)
 {
 	if (x->ust.ust_self != NULL)
 		x->ust.ust_self = (char *)((long)(x->a.a_self) + diff);
@@ -739,21 +774,59 @@ adjust_displaced(object x, int diff)
 static char *
 raw_aet_ptr(object x, short int typ)
 {  /* doubles are the largest raw type */
-  static double u;
-  if (x==Cnil) return aet_types[typ].dflt;
+
+  static union{
+    object o;char c;fixnum i;shortfloat f;longfloat d;
+    unsigned char uc;short s;unsigned short us;} u;
+
+  if (x==Cnil) 
+    return aet_types[typ].dflt;
+
   switch (typ){
-#define STORE_TYPED(pl,type,val) *((type *) pl) = (type) val; break;
-  case aet_object: STORE_TYPED(&u,object,x);
-  case aet_ch:     STORE_TYPED(&u,char, char_code(x));
-  case aet_bit:    STORE_TYPED(&u,fixnum, -Mfix(x));
-  case aet_fix:    STORE_TYPED(&u,fixnum, Mfix(x));
-  case aet_sf:     STORE_TYPED(&u,shortfloat, Msf(x));
-  case aet_lf:     STORE_TYPED(&u,longfloat, Mlf(x));
-  case aet_char:   STORE_TYPED(&u, char, Mfix(x));
-  case aet_uchar:  STORE_TYPED(&u, unsigned char, Mfix(x));
-  case aet_short:  STORE_TYPED(&u, short, Mfix(x));
-  case aet_ushort: STORE_TYPED(&u,unsigned short,Mfix(x));
-  default: FEerror("bad elttype",0);
+/* #define STORE_TYPED(pl,type,val) *((type *) pl) = (type) val; break; */
+  case aet_object: 
+    /* STORE_TYPED(&u,object,x); */
+    u.o=x;
+    break;
+  case aet_ch:     
+    /* STORE_TYPED(&u,char, char_code(x)); */
+    u.c=char_code(x);
+    break;
+  case aet_bit:    
+    /* STORE_TYPED(&u,fixnum, -Mfix(x)); */
+    u.i=-Mfix(x);
+    break;
+  case aet_fix:    
+    /* STORE_TYPED(&u,fixnum, Mfix(x)); */
+    u.i=Mfix(x);
+    break;
+  case aet_sf:     
+    /* STORE_TYPED(&u,shortfloat, Msf(x)); */
+    u.f=Msf(x);
+    break;
+  case aet_lf:     
+    /* STORE_TYPED(&u,longfloat, Mlf(x)); */
+    u.d=Mlf(x);
+    break;
+  case aet_char:   
+    /* STORE_TYPED(&u, char, Mfix(x)); */
+    u.c=(char)Mfix(x);
+    break;
+  case aet_uchar:  
+    /* STORE_TYPED(&u, unsigned char, Mfix(x)); */
+    u.uc=(unsigned char)Mfix(x);
+    break;
+  case aet_short:  
+    /* STORE_TYPED(&u, short, Mfix(x)); */
+    u.s=(short)Mfix(x);
+    break;
+  case aet_ushort: 
+    /* STORE_TYPED(&u,unsigned short,Mfix(x)); */
+    u.us=(unsigned short)Mfix(x);
+    break;
+  default: 
+    FEerror("bad elttype",0);
+    break;
   }
   return (char *)&u;
 }
@@ -999,6 +1072,7 @@ Icheck_displaced(object displaced_list, object ar, int dim)
 { 
   while (displaced_list!=Cnil)
     { object u = Mcar(displaced_list);
+      displaced_list = Mcdr(displaced_list);
       if (u->a.a_self == NULL) continue;
       if ((Iarray_element_type(u) == aet_bit &&
 	   (u->bv.bv_self - ar->bv.bv_self)*BV_BITS +u->bv.bv_dim -dim
@@ -1006,7 +1080,6 @@ Icheck_displaced(object displaced_list, object ar, int dim)
 	  || (ARRAY_BODY_PTR(u,u->a.a_dim) > ARRAY_BODY_PTR(ar,dim)))
 	FEerror("Bad displacement",0);
       Icheck_displaced(DISPLACED_FROM(u),ar,dim);
-      displaced_list = Mcdr(displaced_list);
     }
 }
 
@@ -1113,202 +1186,202 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 
 	/* FIXME do this with C macros */
 	switch(i+1){
-	case 3:  (*fSaset)(ind[0],fix(ind[1]),ind[2]);break;
-	case 4:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3]);break;
-	case 5:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4]);break;
-	case 6:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5]);break;
-	case 7:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6]);break;
-	case 8:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7]);break;
-	case 9:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 3:  (*FFN(fSaset))(ind[0],ind[1],ind[2]);break;
+	case 4:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3]);break;
+	case 5:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4]);break;
+	case 6:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5]);break;
+	case 7:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6]);break;
+	case 8:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7]);break;
+	case 9:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 			       ind[8]);break;
-	case 10:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 10:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9]);break;
-	case 11:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 11:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10]);break;
-	case 12:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 12:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11]);break;
-	case 13:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 13:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12]);break;
-	case 14:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 14:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13]);break;
-	case 15:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 15:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14]);break;
-	case 16:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 16:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15]);break;
-	case 17:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 17:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16]);break;
-	case 18:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 18:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17]);break;
-	case 19:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 19:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18]);break;
-	case 20:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 20:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19]);break;
-	case 21:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 21:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20]);break;
-	case 22:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 22:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21]);break;
-	case 23:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 23:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22]);break;
-	case 24:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 24:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23]);break;
-	case 25:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 25:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24]);break;
-	case 26:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 26:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25]);break;
-	case 27:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 27:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26]);break;
-	case 28:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 28:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27]);break;
-	case 29:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 29:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28]);break;
-	case 30:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 30:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29]);break;
-	case 31:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 31:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30]);break;
-	case 32:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 32:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31]);break;
-	case 33:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 33:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32]);break;
-	case 34:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 34:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33]);break;
-	case 35:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 35:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34]);break;
-	case 36:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 36:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35]);break;
-	case 37:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 37:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36]);break;
-	case 38:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 38:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37]);break;
-	case 39:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 39:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38]);break;
-	case 40:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 40:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39]);break;
-	case 41:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 41:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40]);break;
-	case 42:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 42:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41]);break;
-	case 43:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 43:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42]);break;
-	case 44:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 44:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43]);break;
-	case 45:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 45:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44]);break;
-	case 46:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 46:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45]);break;
-	case 47:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 47:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46]);break;
-	case 48:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 48:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47]);break;
-	case 49:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 49:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48]);break;
-	case 50:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 50:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
 				ind[29],ind[30],ind[31],ind[32],ind[33],ind[34],ind[35],
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49]);break;
-	case 51:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 51:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1316,7 +1389,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50]);break;
-	case 52:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 52:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1324,7 +1397,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51]);break;
-	case 53:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 53:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1332,7 +1405,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52]);break;
-	case 54:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 54:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1340,7 +1413,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53]);break;
-	case 55:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 55:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1348,7 +1421,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54]);break;
-	case 56:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 56:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1356,7 +1429,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55]);break;
-	case 57:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 57:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1364,7 +1437,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[36],ind[37],ind[38],ind[39],ind[40],ind[41],ind[42],
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56]);break;
-	case 58:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 58:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1373,7 +1446,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57]);break;
-	case 59:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 59:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1382,7 +1455,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57],ind[58]);break;
-	case 60:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 60:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1391,7 +1464,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57],ind[58],ind[59]);break;
-	case 61:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 61:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1400,7 +1473,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57],ind[58],ind[59],ind[60]);break;
-	case 62:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 62:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1409,7 +1482,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57],ind[58],ind[59],ind[60],ind[61]);break;
-	case 63:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 63:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1418,7 +1491,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 				ind[43],ind[44],ind[45],ind[46],ind[47],ind[48],ind[49],
 				ind[50],ind[51],ind[52],ind[53],ind[54],ind[55],ind[56],
 				ind[57],ind[58],ind[59],ind[60],ind[61],ind[62]);break;
-	case 64:  (*fSaset)(ind[0],fix(ind[1]),ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
+	case 64:  (*FFN(fSaset))(ind[0],ind[1],ind[2],ind[3],ind[4],ind[5],ind[6],ind[7],
 				ind[8],ind[9],ind[10],ind[11],ind[12],ind[13],ind[14],
 				ind[15],ind[16],ind[17],ind[18],ind[19],ind[20],ind[21],
 				ind[22],ind[23],ind[24],ind[25],ind[26],ind[27],ind[28],
@@ -1434,7 +1507,7 @@ DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
 }
 
 void
-init_array_function(void) {
+gcl_init_array_function(void) {
   make_function("ARRAY-DISPLACEMENT", Larray_displacement);
 }
      
