@@ -11,26 +11,27 @@ static void
 sgc_mark_object1(object);
 
 static void
-sgc_mprotect(int, int, int);
+sgc_mprotect(long, long, int);
 
 
 #ifdef BSD
 /* ulong may have been defined in mp.h but the define is no longer needed */
 #undef ulong
 #include <sys/mman.h>
-#define PROT_READ_WRITE (PROT_READ | PROT_WRITE |PROT_EXEC)
+#define PROT_READ_WRITE_EXEC (PROT_READ | PROT_WRITE |PROT_EXEC)
+#define PROT_READ_EXEC (PROT_READ|PROT_EXEC)
 #endif
 #ifdef AIX3
 #include <sys/vmuser.h>
-#define PROT_READ RDONLY
-#define  PROT_READ_WRITE UDATAKEY
+#define PROT_READ_EXEC RDONLY /*FIXME*/
+#define  PROT_READ_WRITE_EXEC UDATAKEY
 int mprotect();
 #endif
 
 #ifdef __MINGW32__
 #include <windows.h>
-#define PROT_READ_WRITE PAGE_EXECUTE_READWRITE
-#define PROT_READ PAGE_READONLY
+#define PROT_READ_WRITE_EXEC PAGE_EXECUTE_READWRITE
+#define PROT_READ_EXEC PAGE_READONLY /*FIXME*/
 
 int gclmprotect ( void *addr, size_t len, int prot ) {
     int old, rv;
@@ -48,6 +49,10 @@ int gclmprotect ( void *addr, size_t len, int prot ) {
 
 #endif
 
+#if defined(DARWIN)
+#include <sys/ucontext.h>
+#endif
+
 #include <signal.h>
 
 /*  void segmentation_catcher(void); */
@@ -308,7 +313,7 @@ sgc_mark_object1(object x) {
 	;
       else if (x->a.a_displaced == Cnil) {
 #ifdef HAVE_ALLOCA
-	if (cp <= core_end)  /* only if body of array not on C stack */
+	if (!NULL_OR_ON_C_STACK(cp))  /* only if body of array not on C stack */
 #endif			  
 	  x->a.a_self = (object *)copy_relblock(cp, j);
       }
@@ -594,7 +599,8 @@ sgc_mark_object1(object x) {
 static void
 sgc_mark_stack_carefully(void *topv, void *bottomv, int offset) {
   
-  int p,m,pageoffset;
+  long m,pageoffset;
+  unsigned long p;
   object x;
   struct typemanager *tm;
   register long *j;
@@ -626,7 +632,7 @@ sgc_mark_stack_carefully(void *topv, void *bottomv, int offset) {
 	if (m==TRUE) continue;
 	if (m!=0) {
 	  fprintf(stdout,
-		  "**bad value %d of d.m in gbc page %d skipping mark**"
+		  "**bad value %ld of d.m in gbc page %ld skipping mark**"
 		  ,m,p);fflush(stdout);
 	  continue;
 	}
@@ -639,7 +645,7 @@ sgc_mark_stack_carefully(void *topv, void *bottomv, int offset) {
 static void
 sgc_mark_phase(void) {
 
-  STATIC int i, j;
+  STATIC long i, j;
   STATIC struct package *pp;
   STATIC bds_ptr bdp;
   STATIC frame_ptr frp;
@@ -650,7 +656,7 @@ sgc_mark_phase(void) {
   
   /* mark all non recent data on writable pages */
   {
-    int t,i=page(heap_end);
+    long t,i=page(heap_end);
     struct typemanager *tm;
     char *p;
     
@@ -751,7 +757,7 @@ sgc_mark_phase(void) {
 
 static void
 sgc_sweep_phase(void) {
-  STATIC int i, j, k;
+  STATIC long i, j, k;
   STATIC object x;
   STATIC char *p;
   STATIC struct typemanager *tm;
@@ -867,7 +873,7 @@ sgc_sweep_phase(void) {
 static void
 sgc_contblock_sweep_phase(void) {
 
-  STATIC int i, j;
+  STATIC long i, j;
   STATIC char *s, *e, *p, *q;
   STATIC struct contblock *cbp;
   
@@ -887,19 +893,24 @@ sgc_contblock_sweep_phase(void) {
     e = pagetochar(j);
     for (p = s;  p < e;) {
       if (get_mark_bit((int *)p)) {
-	p += PTR_ALIGN;
+	/* SGC cont pages: cont blocks must be no smaller than
+	   sizeof(struct contblock), and must not have a sweep
+	   granularity greater than this amount (e.g. CPTR_ALIGN) if
+	   contblock leaks are to be avoided.  Used to be aligned at
+	   PTR_ALIGN. CM 20030827 */
+	p += CPTR_ALIGN;
 	continue;
       }
-      q = p + PTR_ALIGN;
+      q = p + CPTR_ALIGN;
       while (q < e) {
 	if (!get_mark_bit((int *)q)) {
-	  q += PTR_ALIGN;
+	  q += CPTR_ALIGN;
 	  continue;
 	}
 	break;
       }
       insert_contblock(p, q - p);
-      p = q + PTR_ALIGN;
+      p = q + CPTR_ALIGN;
     }
     i = j + 1;
   }
@@ -937,9 +948,9 @@ sgc_count(object yy) {
 static int
 sgc_count_writable(int end) { 
 
-  int j = first_protectable_page -1;
-  int count = 0;
-  int hp_end= page(heap_end);
+  unsigned long j = first_protectable_page -1;
+  unsigned long count = 0;
+  unsigned long hp_end= page(heap_end)-1;
   while(j++ < hp_end)
     if (WRITABLE_PAGE_P(j)) count++;
   j= page(rb_start);
@@ -952,29 +963,256 @@ sgc_count_writable(int end) {
 int
 sgc_count_type(int t) {
 
-  int j = first_protectable_page -1;
-  int end = page(core_end);
-  int count=0;
+  unsigned long j = first_protectable_page -1;
+  unsigned long end = page(core_end)-1;
+  unsigned long count=0;
+  /* FIXME  ensure core_end in range for type_map reference below.  CM*/
   while(j++ < end)
     if (type_map[j]==t && SGC_PAGE_P(j))
       count++;
   return count;
 }
 
+int
+sgc_count_read_only_type(int t) {
+
+  unsigned long j = first_protectable_page -1;
+  unsigned long hp_end = page(heap_end)-1;
+  unsigned long end = page(rb_limit)-1;
+  unsigned long count=0;
+  while(j++ < hp_end)
+    if ((type_map[j]==t || (t<0 && type_map[j]!=t_other)) && !WRITABLE_PAGE_P(j))
+      count++;
+  j= page(rb_start)-1;
+  while(j++ < end) /* FIXME: relocatable pages are marked as type t_other */
+    if ((t==t_relocatable || t<0) && !WRITABLE_PAGE_P(j))
+      count++;
+  return count;
+}
+
+#ifdef SGC_CONT_DEBUG
+void
+overlap_check(struct contblock *t1,struct contblock *t2) {
+
+  struct contblock *p;
+
+  for (;t1;t1=t1->cb_link) {
+
+    if (!inheap(t1)) {
+      fprintf(stderr,"%p not in heap\n",t1);
+      exit(1);
+    }
+
+    for (p=t2;p;p=p->cb_link) {
+
+      if (!inheap(p)) {
+	fprintf(stderr,"%p not in heap\n",t1);
+	exit(1);
+      }
+
+      if ((p<=t1 && (void *)p+p->cb_size>(void *)t1) ||
+	  (t1<=p && (void *)t1+t1->cb_size>(void *)p)) {
+	fprintf(stderr,"Overlap %u %p  %u %p\n",t1->cb_size,t1,p->cb_size,p);
+	exit(1);
+      }
+      
+      if (p==p->cb_link) {
+	fprintf(stderr,"circle detected at %p\n",p);
+	exit(1);
+      }
+
+    }
+	
+    if (t1==t1->cb_link) {
+      fprintf(stderr,"circle detected at %p\n",t1);
+      exit(1);
+    }
+
+  }
+
+}
+
+void
+tcc(struct contblock *t) {
+
+  for (;t;t=t->cb_link) {
+
+    if (!inheap(t)) {
+      fprintf(stderr,"%p not in heap\n",t);
+      break;
+    }
+
+    fprintf(stderr,"%u at %p\n",t->cb_size,t);
+
+    if (t==t->cb_link) {
+      fprintf(stderr,"circle detected at %p\n",t);
+      break;
+    }
+
+  }
+
+}
+
+#endif	  
+
+typedef enum {memprotect_none,memprotect_cannot_protect,memprotect_sigaction,
+	      memprotect_bad_return,memprotect_no_signal,
+	      memprotect_multiple_invocations,memprotect_no_restart,
+	      memprotect_bad_fault_address,memprotect_success} memprotect_enum;
+static memprotect_enum memprotect_result;
+static int memprotect_handler_invocations,memprotect_print_enable;
+static void *memprotect_test_address;
+
+#define MEM_ERR_CASE(a_) \
+  case a_: \
+    fprintf(stderr,"The SGC segfault recovery test failed with %s, SGC disabled\n",#a_); \
+    break
+
+static void
+memprotect_print(void) {
+
+  if (!memprotect_print_enable)
+    return;
+
+  switch(memprotect_result) {
+  case memprotect_none: case memprotect_success:
+    break;
+
+    MEM_ERR_CASE(memprotect_cannot_protect);
+    MEM_ERR_CASE(memprotect_sigaction);
+    MEM_ERR_CASE(memprotect_bad_return);
+    MEM_ERR_CASE(memprotect_no_signal);
+    MEM_ERR_CASE(memprotect_no_restart);
+    MEM_ERR_CASE(memprotect_bad_fault_address);
+    MEM_ERR_CASE(memprotect_multiple_invocations);
+
+  }
+
+}
+
+
+static void
+memprotect_handler_test(int sig, long code, void *scp, char *addr) {
+
+  char *faddr;
+  faddr=GET_FAULT_ADDR(sig,code,scp,addr); 
+
+  if (memprotect_handler_invocations) {
+    memprotect_result=memprotect_multiple_invocations;
+    exit(-1);
+  }
+  memprotect_handler_invocations=1;
+  if (faddr!=memprotect_test_address)
+    memprotect_result=memprotect_bad_fault_address;
+  else
+    memprotect_result=memprotect_none;
+  mprotect(memprotect_test_address,PAGESIZE,PROT_READ_WRITE_EXEC);
+
+}
+
+static int
+memprotect_test(void) {
+
+  char b1[2*PAGESIZE],b2[PAGESIZE];
+  struct sigaction sa,sao,saob;
+
+  if (memprotect_result!=memprotect_none)
+    return memprotect_result!=memprotect_success;
+  if (atexit(memprotect_print)) {
+    fprintf(stderr,"Cannot setup memprotect_print on exit\n");
+    exit(-1);
+  }
+
+  memset(b1,32,sizeof(b1));
+  memset(b2,0,sizeof(b2));
+  memprotect_test_address=(void *)(((unsigned long)b1+PAGESIZE-1) & ~(PAGESIZE-1));
+  if (mprotect(memprotect_test_address,PAGESIZE,PROT_READ_EXEC)) {
+    memprotect_result=memprotect_cannot_protect;
+    return -1;
+  }
+  sa.sa_sigaction=(void *)memprotect_handler_test;
+  sa.sa_flags=MPROTECT_ACTION_FLAGS;
+  if (sigaction(SIGSEGV,&sa,&sao)) {
+    memprotect_result=memprotect_sigaction;
+    return -1;
+  }
+  if (sigaction(SIGBUS,&sa,&saob)) {
+    sigaction(SIGSEGV,&sao,NULL);
+    memprotect_result=memprotect_sigaction;
+    return -1;
+  }
+  memprotect_result=memprotect_bad_return;
+  memset(memprotect_test_address,0,PAGESIZE);
+  if (memprotect_result==memprotect_bad_return)
+    memprotect_result=memprotect_no_signal;
+  if (memprotect_result!=memprotect_none) {
+    sigaction(SIGSEGV,&sao,NULL);
+    sigaction(SIGBUS,&saob,NULL);
+    return -1;
+  }
+  if (memcmp(memprotect_test_address,b2,PAGESIZE)) {
+    memprotect_result=memprotect_no_restart;
+    sigaction(SIGSEGV,&sao,NULL);
+    sigaction(SIGBUS,&saob,NULL);
+    return -1;
+  }
+  memprotect_result=memprotect_success;
+  sigaction(SIGSEGV,&sao,NULL);
+  sigaction(SIGBUS,&saob,NULL);
+  return 0;
+
+}
+
+static int
+do_memprotect_test(void) {
+
+  int rc=0;
+
+  memprotect_print_enable=1;
+  if (memprotect_test()) {
+    memprotect_print();
+    if (sgc_enabled)
+      sgc_quit();
+    rc=-1;
+  }
+  memprotect_print_enable=0;
+  return rc;
+
+}
+
+void
+memprotect_test_reset(void) {
+
+  memprotect_result=memprotect_none;
+  memprotect_handler_invocations=0;
+  memprotect_test_address=NULL;
+
+  if (sgc_enabled)
+    do_memprotect_test();
+
+}
+
 int
 sgc_start(void) {
 
-  int i;
-  int np;
-  short free_map[MAXPAGE];
+  long i;
+  long np;
+  unsigned short free_map[MAXPAGE];
   object f;
   struct typemanager *tm;
-  int npages;
-  if (sgc_type_map[page((&sgc_type_map[0]))] != SGC_PERM_WRITABLE)
+  long npages;
+  unsigned long npp;
+
+  if (memprotect_result!=memprotect_success && do_memprotect_test())
+    return 0;
+
+  npp=page((&sgc_type_map[0]));
+  if (npp<MAXPAGE && sgc_type_map[npp] != SGC_PERM_WRITABLE)
     perm_writable(&sgc_type_map[0],sizeof(sgc_type_map));
   if (sgc_enabled)
     return 1;
   sgc_type_map[0]=0;
+  /* FIXME ensure core_end in range for type_map reference below.  CM*/
   i=npages=page(core_end);
   while (i--> 0)
     sgc_type_map[i] = sgc_type_map[i]  & SGC_PERM_WRITABLE ;
@@ -983,15 +1221,23 @@ sgc_start(void) {
     if (TM_BASE_TYPE_P(i) && (np=(tm=tm_of(i))->tm_sgc)) 
       FIND_FREE_PAGES:
     {
-      int maxp=0;
-      int j;
-      int minfree = tm->tm_sgc_minfree;
-      int count;
+      unsigned long maxp=0;
+      unsigned long j;
+      /* SGC cont pages: This used to be simply set to tm_sgc_minfree,
+	 which is a definite bug, as minfree could then be zero,
+	 leading this type to claim SGC pages not of its type as
+	 specified in type_map.  CM 20030827*/
+      unsigned short minfree = tm->tm_sgc_minfree > 0 ? tm->tm_sgc_minfree : 1 ;
+      unsigned long count;
       bzero(free_map,npages*sizeof(short));
       f = tm->tm_free;
       count=0;
       while (f!=0) {
-	free_map[j=page(f)]++;
+	j=page(f);
+	if (j>=MAXPAGE)
+	  error("Address in tm freelist out of range");
+	/* protect against overflow */
+	free_map[j]=free_map[j]<minfree ? free_map[j]+1 : free_map[j];
 	if (j>=maxp) maxp=j;
 #ifdef DEBUG
 	count++;
@@ -1000,7 +1246,7 @@ sgc_start(void) {
       }
 #ifdef DEBUG       
       if (count!=tm->tm_nfree) 
-	printf("[Count differed type(%d)nfree= %d in freelist %d]\n"
+	printf("[Count differed type(%d)nfree= %ld in freelist %ld]\n"
 	       ,tm->tm_type,tm->tm_nfree,
 	       count);fflush(stdout);
 #endif       
@@ -1019,8 +1265,8 @@ sgc_start(void) {
       
       if (count < tm->tm_sgc) {
 	/* try to get some more free pages of type i */
-	int n = tm->tm_sgc - count;
-	int again=0,nfree = tm->tm_nfree;
+	long n = tm->tm_sgc - count;
+	long again=0,nfree = tm->tm_nfree;
 	char *p=alloc_page(n);
 	if (tm->tm_nfree > nfree) again=1;  /* gc freed some objects */
 	while (n-- > 0) {
@@ -1031,21 +1277,132 @@ sgc_start(void) {
 	  goto FIND_FREE_PAGES;	 
       }
     }
+
+/* SGC cont pages: Here we implement the contblock page division into
+   SGC and non-SGC types.  Unlike the other types, we need *whole*
+   free pages for contblock SGC, as there is no psersistent data
+   element (e.g. .m) on an allocated block itself which can indicate
+   its live status.  If anything on a page which is to be marked
+   read-only points to a live object on an SGC cont page, it will
+   never be marked and will be erroneously swept.  It is also possible
+   for dead objects to unnecessarily mark dead regions on SGC pages
+   and delay sweeping until the pointing type is GC'ed if SGC is
+   turned off for the pointing type, e.g. tm_sgc=0. (This was so by
+   default for a number of types, including bignums, and has now been
+   corrected in gcl_init_alloc in alloc.c.) We can't get around this
+   AFAICT, as old data on (writable) SGC pages must be marked lest it
+   is lost, and (old) data on now writable non-SGC pages might point
+   to live regions on SGC pages, yet might not themselves be reachable
+   from the mark origin through an unbroken chain of writable pages.
+   In any case, the possibility of a lot of garbage marks on contblock
+   pages, especially when the blocks are small as in bignums, makes
+   necessary the sweeping of minimal contblocks to prevent leaks. CM
+   20030827 */
+  {
+
+    void *p=NULL;
+    unsigned long i,j,k,count;
+    struct contblock *new_cb_pointer=NULL,*tmp_cb_pointer=NULL,**cbpp;
+    
+    tm=tm_of(t_contiguous);
+    
+    /* SGC cont pages:  First count whole free pages available.  CM 20030827 */
+    for (cbpp=&cb_pointer,count=0;*cbpp;cbpp=&(*cbpp)->cb_link) {
+      p=PAGE_ROUND_UP((void *)(*cbpp));
+      k=p-((void *)(*cbpp));
+      if ((*cbpp)->cb_size<k || (*cbpp)->cb_size-k<PAGESIZE) 
+	continue;
+      i=((*cbpp)->cb_size-k)/PAGESIZE;
+      count+=i;
+    }
+    count=tm->tm_sgc>count ? tm->tm_sgc - count : 0;
+    
+    if (count>0) {
+      /* SGC cont pages: allocate more if necessary, dumping possible
+	 GBC freed pages onto the old contblock list.  CM 20030827*/
+      unsigned long z=count+1;
+      void *p1=alloc_contblock(z*PAGESIZE);
+      p=PAGE_ROUND_UP(p1);
+      if (p>p1) {
+	z--;
+	insert_contblock(p1,p-p1);
+	insert_contblock(p+z*PAGESIZE,PAGESIZE-(p-p1));
+      }
+      tmp_cb_pointer=cb_pointer;
+      cb_pointer=new_cb_pointer;
+      /* SGC cont pages: add new pages to new contblock list. p is not
+	 already on any list as ensured by alloc_contblock.  CM
+	 20030827 */
+      insert_contblock(p,PAGESIZE*z);
+      new_cb_pointer=cb_pointer;
+      cb_pointer=tmp_cb_pointer;
+      
+      i=page(p);
+      k=i+z;
+      if (i>=MAXPAGE || k>MAXPAGE)
+	error("Pages out of range in sgc_start");
+      for (;i<k;i++) 
+	sgc_type_map[i]|= SGC_PAGE_FLAG;
+    }
+
+    for (cbpp=&cb_pointer;*cbpp;) {
+      p=PAGE_ROUND_UP((void *)(*cbpp));
+      k=p-((void *)(*cbpp));
+      if ((*cbpp)->cb_size<k || (*cbpp)->cb_size-k<PAGESIZE) {
+	cbpp=&(*cbpp)->cb_link;
+	continue;
+      }
+      i=((*cbpp)->cb_size-k)/PAGESIZE;
+      i*=PAGESIZE;
+      j=(*cbpp)->cb_size-i-k;
+      /* SGC contblock pages:  remove this block from old list CM 20030827 */
+      *cbpp=(*cbpp)->cb_link;
+      /* SGC contblock pages:  add fragments old list CM 20030827 */
+      if (k) {
+	ncb--;
+	insert_contblock(p-k,k);
+      }
+      if (j) {
+	ncb--;
+	insert_contblock(p+i,j);
+      }
+      tmp_cb_pointer=cb_pointer;
+      cb_pointer=new_cb_pointer;
+      /* SGC contblock pages: add whole pages to new list, p p-k, and
+	 p+i are guaranteed to be distinct when used. CM 20030827 */
+      insert_contblock(p,i);
+      new_cb_pointer=cb_pointer;
+      cb_pointer=tmp_cb_pointer;
+      i/=PAGESIZE;
+      j=page(p);
+      i+=j;
+      if (j>=MAXPAGE || i>MAXPAGE)
+	error("Pages out of range in sgc_start");
+      for (;j<i;j++)
+	sgc_type_map[j]|= SGC_PAGE_FLAG;
+    }
+
+    /* SGC contblock pages: switch to new free SGC contblock list. CM
+       20030827 */
+    old_cb_pointer=cb_pointer;
+    cb_pointer=new_cb_pointer;
+
+#ifdef SGC_CONT_DEBUG
+    overlap_check(old_cb_pointer,cb_pointer);
+#endif
+
+  }
+
   /* Now  allocate the sgc relblock.   We do this as the tail
      end of the ordinary rb.     */  
   {
-    int want;
     char *new;
     tm=tm_of(t_relocatable);
-    want =((int) (rb_end - rb_pointer) >> PAGEWIDTH);
-    if (want < tm->tm_sgc) want = tm->tm_sgc;
-    else 
-      want  = (want < 4 ? want : want -2);
     
     {
       old_rb_start=rb_start;
       if(!saving_system) {
-	new=alloc_relblock(want*PAGESIZE);
+	new=alloc_relblock(((unsigned long)tm->tm_sgc)*PAGESIZE);
 	/* the above may cause a gc, shifting the relblock */
 	old_rb_start=rb_start;
 	new= PAGE_ROUND_UP(new);
@@ -1117,6 +1474,26 @@ sgc_quit(void) {
     return 0;
   sgc_enabled=0;
   rb_start = old_rb_start;
+
+  /* SGC cont pages: restore contblocks, each tmp_cb_pointer coming
+     from the new list is guaranteed not to be on the old. Need to
+     grab 'next' before insert_contblock writes is.  CM 20030827 */
+  {
+
+    struct contblock *tmp_cb_pointer,*next;
+    if (old_cb_pointer) {
+#ifdef SGC_CONT_DEBUG
+      overlap_check(old_cb_pointer,cb_pointer);
+#endif
+      tmp_cb_pointer=cb_pointer;
+      cb_pointer=old_cb_pointer;
+      for (;tmp_cb_pointer;  tmp_cb_pointer=next) {
+	next=tmp_cb_pointer->cb_link;
+	insert_contblock((void *)tmp_cb_pointer,tmp_cb_pointer->cb_size);
+      }
+    }
+  }
+
   for (i= t_start; i < t_contiguous ; i++)
     if (TM_BASE_TYPE_P(i)) {
       tm=tm_of(i);
@@ -1157,8 +1534,8 @@ sgc_quit(void) {
 	
 	/* remove the recent flag from any objects on sgc pages */
 	{
-	  int hp=page(heap_end);
-	  int i,j;
+	  unsigned long hp=page(heap_end);
+	  unsigned long i,j;
 	  char t = (char) tm->tm_type;
 	  char *p;
 	  for (i=0 ; i < hp; i++)
@@ -1175,13 +1552,15 @@ sgc_quit(void) {
 }
 
 void
-make_writable(int beg, int i) {
+make_writable(unsigned long beg, unsigned long i) {
 
   if (i > beg) {
     beg=ROUND_DOWN_PAGE_NO(beg);
     i=ROUND_UP_PAGE_NO(i);
     {
-      int k=beg;
+      unsigned long k=beg;
+      if (k>=MAXPAGE || i>MAXPAGE)
+	error("Pages out of range in make_writable");
       while(k <i )
 	sgc_type_map[k++] |= SGC_TEMP_WRITABLE;
     }
@@ -1195,7 +1574,7 @@ extern char etext;
 static void
 memprotect_handler(int sig, long code, void *scp, char *addr) {
   
-  int p;
+  unsigned long p;
   int j=page_multiple;
   char *faddr;  /* Needed because we must not modify signal handler
 		   arguments on the stack! */
@@ -1225,7 +1604,9 @@ memprotect_handler(int sig, long code, void *scp, char *addr) {
 	   pagetochar(p),page_multiple * PAGESIZE, sbrk(0));
     fflush(stdout);
 #endif     
-    mprotect(pagetochar(p),page_multiple * PAGESIZE, PROT_READ_WRITE);
+    mprotect(pagetochar(p),page_multiple * PAGESIZE, PROT_READ_WRITE_EXEC);
+    if (p>=MAXPAGE || p+j>MAXPAGE)
+      error("Pages out of range in memprotect_handler");
     while (--j >= 0)
       sgc_type_map[p+j] = sgc_type_map[p+j] | SGC_TEMP_WRITABLE;
     
@@ -1239,13 +1620,13 @@ memprotect_handler(int sig, long code, void *scp, char *addr) {
 #ifndef  BSD
   INSTALL_MPROTECT_HANDLER;
 #endif
-  /* if (SIGSEGV == SIGPROTV) */
-  segmentation_catcher(SIGSEGV);
+
+  segmentation_catcher(0);
 
 }
 
 static void
-sgc_mprotect(int pbeg, int n, int writable) {
+sgc_mprotect(long pbeg, long n, int writable) {
   /* CHECK_RANGE(pbeg,n);  */
 #ifdef DEBUG_MPROTECT
   printf("prot[%d,%d,(%d),%s]\n",pbeg,pbeg+n,writable & SGC_WRITABLE,
@@ -1255,7 +1636,7 @@ sgc_mprotect(int pbeg, int n, int writable) {
   fflush(stdout);
 #endif  
   if(mprotect(pagetochar(pbeg),n*PAGESIZE,
-	      (writable & SGC_WRITABLE ? PROT_READ_WRITE : PROT_READ)))
+	      (writable & SGC_WRITABLE ? PROT_READ_WRITE_EXEC : PROT_READ_EXEC)))
     FEerror("Couldn't protect",0);
 }
 
@@ -1265,9 +1646,9 @@ sgc_mprotect(int pbeg, int n, int writable) {
    rest must be */
 
 static void
-fix_for_page_multiple(int beg, int end) {
+fix_for_page_multiple(unsigned long beg, unsigned long end) {
 
-  int i,j;
+  unsigned long i,j;
   char *p;
   int writable;
 
@@ -1298,9 +1679,9 @@ fix_for_page_multiple(int beg, int end) {
 void
 memory_protect(int on) {
 
-  int i,beg,end= page(core_end);
+  unsigned long i,beg,end= page(core_end);
   int writable=1;
-  extern void   install_segmentation_catcher(void);
+  extern void install_segmentation_catcher(void);
 
   if (first_protectable_page==0) {
     for (i=page_multiple; i< maxpage ; i++)
@@ -1346,7 +1727,7 @@ memory_protect(int on) {
 }
 
 static void
-siLsgc_on(void) {
+FFN(siLsgc_on)(void) {
 
   if (vs_base==vs_top) {
     vs_base[0]=(sgc_enabled ? Ct :Cnil);
@@ -1355,20 +1736,23 @@ siLsgc_on(void) {
   check_arg(1);
   if(vs_base[0]==Cnil) 
     sgc_quit();
-  else sgc_start();
+  else 
+    vs_base[0]=sgc_start() ? Ct : Cnil;
 }
 
 /* make permanently writable pages containing pointers p thru p+n-1 */
 
 void
-perm_writable(char *p, int n) {
+perm_writable(char *p, long n) {
 
-  int beg=page(p);
-  int end=page(PAGE_ROUND_UP(p+n));
-  int i,must_protect=0;
+  unsigned long beg=page(p);
+  unsigned long end=page(PAGE_ROUND_UP(p+n));
+  unsigned long i,must_protect=0;
 
   beg = ROUND_DOWN_PAGE_NO(beg);
   end = ROUND_UP_PAGE_NO(end);
+  if (beg >= MAXPAGE || end >MAXPAGE)
+    error("Address supplied to perm_writable out of range");
   for (i=beg ; i < end ; i++) {
     if (sgc_enabled & !(WRITABLE_PAGE_P(i))) 
       must_protect = 1;
@@ -1382,93 +1766,3 @@ void
 system_error(void) {
   FEerror("System error",0);
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
