@@ -145,12 +145,12 @@ char safety_required[]={XX,XX,XX,XX,XX,XX,XX,XX,
 			XX,XX,XX,XX,XX,XX,XX,XX};
 
 void
-init_safety(void)
+gcl_init_safety(void)
 { safety_required[SIGINT]=sig_try_to_delay;
   safety_required[SIGALRM]=sig_normal;
 }
   
-DO_INIT(init_safety();)
+DO_INIT(gcl_init_safety();)
 DEFUN_NEW("SIGNAL-SAFETY-REQUIRED",object,sSsignal_safety_required,SI,2,2,
 	  NONE,OI,IO,OO,OO,(fixnum signo,fixnum safety),
       "Set the safety level required for handling SIGNO to SAFETY, or if \
@@ -253,8 +253,10 @@ before_interrupt(struct save_for_interrupt *p, int allowed)
  SS1(p->ihs_topVAL,*ihs_top);
  { void **pp = p->save_objects;
 #undef XS
- /* #define XS(a) *pp++ = (void *) (a); */
-#define XS(a) *pp++ =  * (void **) (&a); 
+#undef XSI
+#define XS(a) *pp++ = (void *) (a);
+#define XSI(a) *pp++ = (void *)(long)(a);
+/* #define XS(a) *pp++ =  * (void **) (&a);  */
 #include "usig2_aux.c"
    if ((pp - (&(p->save_objects)[0])) >= (sizeof(p->save_objects)/sizeof(void *)))
      abort();
@@ -309,12 +311,15 @@ after_interrupt(struct save_for_interrupt *p, int allowed)
   RS1(p->ihs_topVAL,*ihs_top);
  { void **pp = p->save_objects;
 #undef XS
+#undef XSI
 
  /*  #define XS(a) a = (void *)(*pp++)
      We store back in the location 'a' the value we have saved. 
   */
  
-#define XS(a) do { void **_p = (void **)(&a); *_p = (void *)(*pp++);}while(0)
+/* #define XS(a) do { void **_p = (void **)(&a); *_p = (void *)(*pp++);}while(0) */
+#define XS(a) a = (void *)(*pp++)
+#define XSI(a) {union {void *v;long l;}u; u.v=*pp++; a = u.l;}
 #include "usig2_aux.c"
  }
 
